@@ -55,6 +55,8 @@ interoptopus::inventory!(
         functions::generic_2,
         functions::generic_3,
         functions::generic_4,
+        functions::array_1,
+        // functions::array_2,
         functions::documented,
         functions::ambiguous_1,
         functions::ambiguous_2,
